@@ -12,11 +12,11 @@ use Memoize;
 
 =head1 VERSION
 
-Version 1.402.8
+Version 1.403.1
 
 =cut
 
-our $VERSION = '1.402.8';
+our $VERSION = '1.403.1';
 
 my %typeregistry = (
     default => {},
@@ -107,7 +107,7 @@ be found (this could be caused by updating the db).
 =cut
 
 sub clear_info_cache {
-    local $@;
+    local ($@);
     eval { Memoize::flush_cache('function_info') };
 }
 
@@ -299,9 +299,10 @@ sub call_procedure {
 
     my @qargs = map { 
                       my $arg = $_;
+                      local ($@);
                       $arg = $arg->to_db if eval {$arg->can('to_db')};
                       $arg = $arg->pgobject_to_db if eval {$arg->can('pgobject_to_db')};
-                      ref ($arg =~ /HASH/) ? $arg->{value} : $arg 
+                      $arg;
                 }  @{$args{args}};
 
     my $argstr = join ', ', map { 
@@ -311,8 +312,10 @@ sub call_procedure {
     my $order = '';
     if ($args{orderby}){
         $order = join(', ', map {
-                                  $_ =~ s/\s+(ASC|DESC)$//i;
-                                  my $dir = $1;
+                                  my $dir = undef;
+                                  if ( s/\A\s+(ASC|DESC)\s*\z//i ) {
+                                      $dir = $1;
+                                  }
                                   defined $dir ? $dbh->quote_identifier($_)
                                                   . " $dir"
                                                : $dbh->quote_identifier($_);
@@ -331,9 +334,6 @@ sub call_procedure {
 
     my $place = 1;
 
-    # This is needed to support byteas, which rquire special escaping during
-    # the binding process.  --Chris T
-
     foreach my $carg (@qargs){
         if (ref($carg) =~ /HASH/){
             $sth->bind_param($place, $carg->{value},
@@ -343,6 +343,7 @@ sub call_procedure {
             # This is used to support arrays of db-aware types.  Long-run 
             # I think we should merge bytea support into this framework. --CT
             if (ref($carg) =~ /ARRAY/){
+               local ($@);
                if (eval{$carg->[0]->can('to_db')}){
                   for my $ref(@$carg){
                        $ref = $ref->to_db;
@@ -391,7 +392,7 @@ sub process_type {
 
     $registry = $typeregistry{$registry} unless ref $registry;
     # Array handling as we'd get this usually from DBD::Pg or equivalent
-    if (ref $val =~ /ARRAY/){
+    if (ref $val and ref($val) =~ /ARRAY/){
        # strangely, DBD::Pg returns, as of 2.x, the types of array types 
        # as prefixed with an underscore.  So we have to remove this. --CT
        $type =~ s/^\_//;
@@ -657,7 +658,7 @@ L<http://search.cpan.org/dist/PGObject/>
 This code has been loosely based on code written for the LedgerSMB open source 
 accounting and ERP project.  While that software uses the GNU GPL v2 or later,
 this is my own reimplementation, based on my original contributions to that 
-project alone, and it differs in signficant ways.   This being said, without
+project alone, and it differs in significant ways.   This being said, without
 LedgerSMB, this module wouldn't exist, and without the lessons learned there, 
 and the great people who have helped make this possible, this framework would 
 not be half of what it is today.
